@@ -85,7 +85,19 @@ check.ErgmTerm <- function(nw, arglist, directed=NULL, bipartite=NULL,
       }
     }
   }
-  c(.conflicts.OK=TRUE,out)
+  #  c(.conflicts.OK=TRUE,out)
+  out
+}
+
+# The following short function takes a list as an argument and creates a variable
+# out of each of its elements *in the calling environment*.  In this way, it
+# sort of works like "attach" but without creating a new environment and
+# without all of the headaches that "attach" can give because the variables
+# it creates are not in the correct frame.
+assignvariables <- function(a) {
+  if(length(a)>0)
+    for(i in 1:length(a)) 
+      assign(names(a)[i], a[[i]], envir=parent.frame())
 }
 
 check.ErgmTerm.summarystats <- function(nw, args, ...) {
