@@ -1,7 +1,7 @@
 control.ergm<-function(prop.weights="default",prop.args=NULL,
                        nr.maxit=100, calc.mcmc.se=TRUE, hessian=FALSE,
-                       compress=FALSE,
-                       maxNumDyadTypes=10000, 
+                       compress=TRUE,
+                       maxNumDyadTypes=1e+6, 
                        maxedges=20000,
                        maxchanges=1000000,
                        maxMPLEsamplesize=100000,
