@@ -39,7 +39,10 @@ ergm <- function(formula, theta0="MPLE",
   theta0copy <- theta0
   initialfit <- ergm.initialfit(theta0copy, MLestimate, Clist.initial,
                                 Clist2.initial, model.initial,
-                                MPLEtype=control$MPLEtype, verbose=verbose, ...)
+                                MPLEtype=control$MPLEtype, verbose=verbose, 
+                                compressflag = control$compress,
+                                maxNumDyadTypes=control$maxNumDyadTypes,
+                                ...)
   if (MLestimate && (!ergm.independencemodel(model.initial)
                      || constraints!=(~.))
      || control$force.mcmc) {
