@@ -1,22 +1,7 @@
-/*
- *  File ergm/src/MCMC.h
- *  Part of the statnet package, http://statnetproject.org
- *
- *  This software is distributed under the GPL-3 license.  It is free,
- *  open source, and has the attribution requirements (GPL Section 7) in
- *    http://statnetproject.org/attribution
- *
- * Copyright 2003 Mark S. Handcock, University of Washington
- *                David R. Hunter, Penn State University
- *                Carter T. Butts, University of California - Irvine
- *                Steven M. Goodreau, University of Washington
- *                Martina Morris, University of Washington
- * Copyright 2007 The statnet Development Team
- */
 #ifndef MCMC_H
 #define MCMC_H
 
-#include "edgeTree.h"
+#include "edgetree.h"
 #include "changestats.h"
 #include "model.h"
 
@@ -48,6 +33,7 @@ typedef struct MHproposalstruct {
 } MHproposal;
 
 void MCMC_wrapper (int *heads, int *tails, int *dnedges,
+                   int *maxpossibleedges,
                    int *dn, int *dflag, int *bipartite, 
                    int *nterms, char **funnames,
                    char **sonames, 
@@ -74,10 +60,12 @@ void MetropolisHastings (MHproposal *MHp,
 int CheckTogglesValid(MHproposal *MHp, DegreeBound *bd, Network *nwp);
 int CheckConstrainedTogglesValid(MHproposal *MHp, DegreeBound *bd, Network *nwp);
 void MCMC_global (int *heads, int *tails, int *dnedges,
+      int *maxpossibleedges,
 		  int *dn, int *dflag,  int *bipartite,
 		  int *nterms, char **funnames,
 		  char **sonames, double *inputs,  double *stats);
 void MCMCPhase12 (int *heads, int *tails, int *dnedges,
+      int *maxpossibleedges,
 		  int *dn, int *dflag, int *bipartite, 
 		  int *nterms, char **funnames,
 		  char **sonames, 
