@@ -11,10 +11,12 @@ void MPLE_wrapper (int *heads, int *tails, int *dnedges,
 		   int *responsevec, double *covmat,
 		   int *weightsvector,
 		   double * offset, double * compressedOffset,
-		   int maxNumDyadTypes, int *maxMPLEsamplesize);
-void MpleInitialize (Vertex bipartite, int *responsevec, double *covmat,
-	             int *weightsvector,
-		     double * offset, double * compressedOffset,
+		   int *maxNumDyadTypes, int *maxMPLEsamplesize, 
+       int *compressflag);
+void MpleInit_hash (int *responsevec, double *covmat, int *weightsvector,
+		    double *offset, double *compressedOffset,
+		    int maxNumDyadTypes, Edge maxMPLE, Network *nwp, Model *m);
+void MpleInit_no_compress (int *responsevec, double *covmat, int *weightsvector,
 		     int maxNumDyadTypes, Edge maxMPLE, Network *nwp, Model *m);
 int rowsAreSame(double *rowA,double *rowB,int rowLength);
 int findCovMatRow(double *newRow,double *matrix, int rowLength, 
